==> pyimfit-0.11.2.tar.gz: pyimfit-0.11.2/docs/acknowledgments.md <==
# Acknowledgments

PyImfit is based on André Luiz de Amorim's [python-imfit](https://github.com/streeto/python-imfit) wrapper 
about an earlier version of **Imfit**.



## Imfit-related Acknowledgements

Major inspirations for **Imfit** include both GALFIT and BUDDA.

Thanks also to Michael Opitsch and Michael Williams for being (partly
unwitting) beta testers and for their feedback, to Martin Kuemmel for
suggesting an early improvement (and finding a related bug), to Roberto
Saglia for urging me to implement the Core-Sérsic function, and to
Maximilian Fabricius for suggesting improvements to the documentation.
Additional bug reports and suggestions from André Luiz de Amorim,
Giulia Savorgnan, David Streich, Guillermo Barro, Sergio Pascual, Lee
Kelvin, Colleen Gilhuly, Semyeong Oh, Benne Holwerde, David Wilman, 
Iskren Georgiev, Corentin Schreiber, and Dan Prole are gratefully appreciated.


### Data Sources

Sample FITS images for demonstration and testing use are taken
from Data Release 7 of the Sloan Digital Sky Survey. Funding for the creation and distribution of the Sloan
Digital Sky Survey Archive has been provided by the Alfred P. Sloan
Foundation, the Participating Institutions, the National Aeronautics and
Space Administration, the National Science Foundation, the U.S.
Department of Energy, the Japanese Monbukagakusho, and the Max Planck
Society. The SDSS Web site is http://www.sdss.org/.

The SDSS is managed by the Astrophysical Research Consortium
(ARC) for the Participating Institutions.  The Participating
Institutions are The University of Chicago, Fermilab, the Institute for
Advanced Study, the Japan Participation Group, The Johns Hopkins
University, the Korean Scientist Group, Los Alamos National Laboratory,
the Max-Planck-Institute for Astronomy (MPIA), the
Max-Planck-Institute for Astrophysics (MPA), New Mexico State
University, University of Pittsburgh, University of Portsmouth,
Princeton University, the United States Naval Observatory, and the
University of Washington.



### Specific Software Acknowledgments

PyImfit makes use of the following external libraries:

   - [FFTW3](https://www.fftw.org)
   
   - [GNU Scientific Library (GSL)](https://www.gnu.org/software/gsl/)
   
   - [NLopt](https://nlopt.readthedocs.io/en/latest/)

##### Minpack
This product includes software developed by the University of Chicago, as Operator of
the Argonne National Laboratory.

==> pyimfit-0.12.2.tar.gz: pyimfit-0.12.2/docs/acknowledgments.md <==
# Acknowledgments

PyImfit is based on André Luiz de Amorim's [python-imfit](https://github.com/streeto/python-imfit) wrapper 
about an earlier version of **Imfit**.



## Imfit-related Acknowledgements

Major inspirations for **Imfit** include both GALFIT and BUDDA.

Thanks also to Michael Opitsch and Michael Williams for being (partly
unwitting) beta testers and for their feedback, to Martin Kuemmel for
suggesting an early improvement (and finding a related bug), to Roberto
Saglia for urging me to implement the Core-Sérsic function, and to
Maximilian Fabricius for suggesting improvements to the documentation.
Additional bug reports and suggestions from André Luiz de Amorim,
Giulia Savorgnan, David Streich, Guillermo Barro, Sergio Pascual, Lee
Kelvin, Colleen Gilhuly, Semyeong Oh, Benne Holwerde, David Wilman, 
Iskren Georgiev, Corentin Schreiber, Dan Prole, Alex Borlaff, and Daria
Kozlova are gratefully appreciated.


### Data Sources

Sample FITS images for demonstration and testing use are taken
from Data Release 7 of the Sloan Digital Sky Survey. Funding for the creation and distribution of the Sloan
Digital Sky Survey Archive has been provided by the Alfred P. Sloan
Foundation, the Participating Institutions, the National Aeronautics and
Space Administration, the National Science Foundation, the U.S.
Department of Energy, the Japanese Monbukagakusho, and the Max Planck
Society. The SDSS Web site is http://www.sdss.org/.

The SDSS is managed by the Astrophysical Research Consortium
(ARC) for the Participating Institutions.  The Participating
Institutions are The University of Chicago, Fermilab, the Institute for
Advanced Study, the Japan Participation Group, The Johns Hopkins
University, the Korean Scientist Group, Los Alamos National Laboratory,
the Max-Planck-Institute for Astronomy (MPIA), the
Max-Planck-Institute for Astrophysics (MPA), New Mexico State
University, University of Pittsburgh, University of Portsmouth,
Princeton University, the United States Naval Observatory, and the
University of Washington.



### Specific Software Acknowledgments

PyImfit makes use of the following external libraries:

   - [FFTW3](https://www.fftw.org)
   
   - [GNU Scientific Library (GSL)](https://www.gnu.org/software/gsl/)
   
   - [NLopt](https://nlopt.readthedocs.io/en/latest/)

##### Minpack
This product includes software developed by the University of Chicago, as Operator of
the Argonne National Laboratory.
